Crate task_list_parser
task_
list_
parser
0.1.5
All Items
Crate Items
Structs
Enums
Functions
Crate
task_
list_
parser
Structs

Task
List
Grammar
TaskListGrammar
is a parser for task lists using a custom grammar defined in
grammar.pest
. It supports parsing tasks with fields: priority, status, date, and description.
Enums

Rule
Task
Parse
Error
TaskParseError
is an enumeration of possible errors that may occur during task parsing.
Functions

parse_
priority
Parses the priority from a string and returns the priority level (1 to 3).
parse_
year
Parses a year from a string and returns it as
u32
.